#!/bin/bash
#$ -S /bin/bash

###### no need to edit this script

Usage()
{
	echo "Usage: ./make_ENIGMA_LONG_webpage.sh <QC_dir> <longitudinal_ENIGMA_subjects.txt> <outliers_long.txt>"
	echo "Please provide full paths"
		exit 1
}

if [[ $# != 3 ]]
then
Usage
fi	
QCdir=$1
subjects=$2
outliers=$3


if [ ! -d $QCdir ]
then
echo "$QCdir does not exist!"
fi
file=`basename $subjects`
if [[ "$file" == "$subjects" ]]
then
echo "Please provide full paths"
exit 1
fi
if [ ! -f $subjects ]
then
echo "File $subjects does not exist!"
exit 1
fi
file=`basename $outliers`
if [[ "$file" == "$outliers" ]]
then
echo "Please provide full paths"
exit 1
fi
if [ ! -f $outliers ]
then
echo "File $outliers does not exist!"
exit 1
fi

cd $QCdir

# Make a main page containing all subjects IDs

echo "<html>" 														>  ENIGMA_LONG_QC.html
echo "<head>"                                                   							>> ENIGMA_LONG_QC.html
echo "<style type=\"text/css\">"											>> ENIGMA_LONG_QC.html
echo "*"                                                        							>> ENIGMA_LONG_QC.html
echo "{"														>> ENIGMA_LONG_QC.html
echo "margin: 3px;"													>> ENIGMA_LONG_QC.html
echo "padding: 3px;"													>> ENIGMA_LONG_QC.html	
echo "font-family: Verdana, sans-serif;"										>> ENIGMA_LONG_QC.html
echo "}"														>> ENIGMA_LONG_QC.html
echo "html, body"													>> ENIGMA_LONG_QC.html
echo "{"														>> ENIGMA_LONG_QC.html
echo "height: 100%;"													>> ENIGMA_LONG_QC.html
echo "}"														>> ENIGMA_LONG_QC.html
echo "TABLE { table-border=""; }"											>> ENIGMA_LONG_QC.html
echo "TR TD { text-align: left; valign: top; white-space:nowrap; }"							>> ENIGMA_LONG_QC.html
echo "</style>"                                                 							>> ENIGMA_LONG_QC.html
echo "</head>"														>> ENIGMA_LONG_QC.html
echo "<body>" 														>> ENIGMA_LONG_QC.html

NRSUB=`cat $subjects | wc | awk '{ print $1 + 1 }'`
i=1
echo '<p><font size="5">LONGITUDINAL QUALITY CHECKING for the ENIGMA plasticity working group </font><br>'		>> ENIGMA_LONG_QC.html
echo '<hr width="100%">'												>> ENIGMA_LONG_QC.html
echo "<TABLE> <CENTER>" 												>> ENIGMA_LONG_QC.html
echo "<TR>"														>> ENIGMA_LONG_QC.html

while read line
do
sub1=`echo $line | awk '{ print $1 }'`
if (( i > 0 )) 
then
echo '<TD><A HREF="ENIGMA_LONG_Sub'${i}'.html "target="_top">' ${sub1} '</A> '     ' </TD>'           			>> ENIGMA_LONG_QC.html
if [ `expr $i % 4` == 0 ]
  then
echo "</TR><TR>"	 												>> ENIGMA_LONG_QC.html
fi
fi
(( i += 1 ))
done < $subjects
echo "</TR></TABLE></CENTER><hr>"                    								        >> ENIGMA_LONG_QC.html

# Per subject, make a page with the pictures


i=1
while read line
do
sub1=`echo $line | awk '{ print $1 }'`
sub2=`echo $line | awk '{ print $2 }'`
next=`echo $i | awk '{ print $1 + 1 }'`
prev=`echo $i | awk '{ print $1 - 1 }'`
if [[ $next == $NRSUB ]]
then
next=1
fi
if [[ $prev == 0 ]]
then
prev=`echo $NRSUB | awk '{ print $1 - 1}'`
fi

echo "<html>"                                                   							>  ENIGMA_LONG_Sub${i}.html
echo "<head>"                                                   							>> ENIGMA_LONG_Sub${i}.html
echo "<style type=\"text/css\">"                                							>> ENIGMA_LONG_Sub${i}.html
echo "*"                                                        							>> ENIGMA_LONG_Sub${i}.html
echo "{"                                                        							>> ENIGMA_LONG_Sub${i}.html
echo "margin: 3px;"                                            								>> ENIGMA_LONG_Sub${i}.html
echo "padding: 3px;"                                           								>> ENIGMA_LONG_Sub${i}.html
echo "}"                                                        							>> ENIGMA_LONG_Sub${i}.html
echo "html, body"                                               							>> ENIGMA_LONG_Sub${i}.html
echo "{"                                                        							>> ENIGMA_LONG_Sub${i}.html
echo "height: 100%;"                                            							>> ENIGMA_LONG_Sub${i}.html
echo "}"                                                        							>> ENIGMA_LONG_Sub${i}.html
echo "TABLE { table-border=""; }"                               							>> ENIGMA_LONG_Sub${i}.html
echo "TR TD { text-align: left; text-valign: top; }"	                        					>> ENIGMA_LONG_Sub${i}.html
echo "</style>"                                                 							>> ENIGMA_LONG_Sub${i}.html
echo "</head>"                                                  							>> ENIGMA_LONG_Sub${i}.html

echo "<body>"                                                   							>> ENIGMA_LONG_Sub${i}.html

echo '<hr width="100%">'												>> ENIGMA_LONG_Sub${i}.html
echo '<Center><a href="ENIGMA_LONG_Sub'${prev}'.html">Previous Subject</a>&nbsp;-&nbsp;
<a href="ENIGMA_LONG_Sub'${next}'.html">Next Subject</a> </center>' 							>> ENIGMA_LONG_Sub${i}.html
echo '<hr width="100%">' 												>> ENIGMA_LONG_Sub${i}.html

echo "Below you will find the QC pngs for each subject at baseline and follow up and a list of structures these subjects are outliers for. Please note that a small number of outlying structures is to be expected. Pay close attention the structures identified as outliers on baseline-follow up values or left-right differences. These are more likely due to segmentation errors. Baseline and follow-up pictures are shown together for an easier comparison." 	>> ENIGMA_LONG_Sub${i}.html
echo "<br><br>SubjectID baseline: $sub1"										>> ENIGMA_LONG_Sub${i}.html
echo "<br>SubjectID follow-up: $sub2"     	                                        				>> ENIGMA_LONG_Sub${i}.html
NR=`cat $outliers | grep $sub1 | awk 'NR == 1 { print $3 }'`
echo "<br>Total number of outliers: $NR" 	                                                                        >> ENIGMA_LONG_Sub${i}.html

GLOBLOW=`cat $outliers | grep $sub1 | grep GLOB | grep LOW | cut -d' ' -f5-`
GLOBHIGH=`cat $outliers | grep $sub1 | grep GLOB | grep HIGH | cut -d' ' -f5-`
SUBLOW=`cat $outliers | grep $sub1 | grep SUB | grep LOW | cut -d' ' -f5-`
SUBHIGH=`cat $outliers | grep $sub1 | grep SUB | grep HIGH | cut -d' ' -f5-`
CORTLOW=`cat $outliers | grep $sub1 | grep CORT | grep LOW | cut -d' ' -f5-`
CORTHIGH=`cat $outliers | grep $sub1 | grep CORT | grep HIGH | cut -d' ' -f5-`
GLOB=`cat $outliers | grep $sub1 | grep GLOB`
SUB=`cat $outliers | grep $sub1 | grep SUB`
CORT=`cat $outliers | grep $sub1 | grep CORT`
all=`cat $outliers | grep $sub1`

if [[ ${all} != "" ]] 
then
echo "<br><br><b>Please pay attention to the following structures:</b><br><br>"							>> ENIGMA_LONG_Sub${i}.html
echo "<table border=\"1\">"													>> ENIGMA_LONG_Sub${i}.html

if [[ "${GLOB}" != "" ]]
then
echo "<th colspan=\"2\">GLOBAL STRUCTURES</th>"											>> ENIGMA_LONG_Sub${i}.html
echo "<tr><th style=\"vertical-align:top\">LOW VALUES</th><th style=\"vertical-align:top\">HIGH VALUES</th>"			>> ENIGMA_LONG_Sub${i}.html
echo "<tr><td style=\"vertical-align:top\">"											>> ENIGMA_LONG_Sub${i}.html
for j in $GLOBLOW
do
echo "<li> $j </li>"														>> ENIGMA_LONG_Sub${i}.html
done
echo "</ul></td>"														>> ENIGMA_LONG_Sub${i}.html
echo "<td style=\"vertical-align:top\">" 											>> ENIGMA_LONG_Sub${i}.html
for j in $GLOBHIGH
do
echo "<li> $j </li>"                                                                    					>> ENIGMA_LONG_Sub${i}.html
done
echo "</ul></td></tr>"     													>> ENIGMA_LONG_Sub${i}.html
fi
if [[ "${SUB}" != "" ]]
then
echo "<th colspan=\"2\">SUBCORTICAL STRUCTURES</th>"                                                                            >> ENIGMA_LONG_Sub${i}.html
echo "<tr><th style=\"vertical-align:top\">LOW VALUES</th><th style=\"vertical-align:top\">HIGH VALUES</th>"                    >> ENIGMA_LONG_Sub${i}.html
echo "<tr><td style=\"vertical-align:top\">"                                                                                    >> ENIGMA_LONG_Sub${i}.html
for j in $SUBLOW
do
echo "<li> $j </li>"                                                                                                            >> ENIGMA_LONG_Sub${i}.html
done
echo "</ul></td>"                                                                                                               >> ENIGMA_LONG_Sub${i}.html
echo "<td style=\"vertical-align:top\">"                                                                                        >> ENIGMA_LONG_Sub${i}.html
for j in $SUBHIGH
do
echo "<li> $j </li>"                                                                                                            >> ENIGMA_LONG_Sub${i}.html
done
echo "</ul></td></tr>"                                                                                                          >> ENIGMA_LONG_Sub${i}.html
fi
if [[ "${CORT}" != "" ]]
then
echo "<th colspan=\"2\">CORTICAL STRUCTURES</th>"                                                                               >> ENIGMA_LONG_Sub${i}.html
echo "<tr><th style=\"vertical-align:top\">LOW VALUES</th><th style=\"vertical-align:top\">HIGH VALUES</th>"                    >> ENIGMA_LONG_Sub${i}.html
echo "<tr><td style=\"vertical-align:top\">"                                                                                    >> ENIGMA_LONG_Sub${i}.html
for j in $CORTLOW
do
echo "<li> $j </li>"                                                                                                            >> ENIGMA_LONG_Sub${i}.html
done
echo "</ul></td>"                                                                                                               >> ENIGMA_LONG_Sub${i}.html
echo "<td style=\"vertical-align:top\">"                                                                                        >> ENIGMA_LONG_Sub${i}.html
for j in $CORTHIGH
do
echo "<li> $j </li>"                                                                                                            >> ENIGMA_LONG_Sub${i}.html
done
echo "</ul></td></tr>"                                                                                                          >> ENIGMA_LONG_Sub${i}.html
fi



echo "</table>"															>> ENIGMA_LONG_Sub${i}.html

fi

echo "<br> <br> <table cellspacing=\"1\" style=\"width:100%;\">"									>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=8> SUBCORTICAL STRUCTURES </FONT> </th> </tr>"		>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> THALAMUS BASELINE </FONT> </th> </tr>"    		>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/Thal_Axial_25.png\"><img src=\""${sub1}"/Thal_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Thal_Axial_50.png\"><img src=\""${sub1}"/Thal_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Thal_Axial_75.png\"><img src=\""${sub1}"/Thal_Axial_75.png\" width=\"100%\"></a></td>"             	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Thal_Coronal_25.png\"><img src=\""${sub1}"/Thal_Coronal_25.png\" width=\"100%\"></a></td>"         	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Thal_Coronal_50.png\"><img src=\""${sub1}"/Thal_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Thal_Coronal_75.png\"><img src=\""${sub1}"/Thal_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr><th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> THALAMUS FOLLOW UP </FONT> </th></tr>"    		>> ENIGMA_LONG_Sub${i}.html 
echo "<tr><td> <a href=\"file:"${sub2}"/Thal_Axial_25.png\"><img src=\""${sub2}"/Thal_Axial_25.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Thal_Axial_50.png\"><img src=\""${sub2}"/Thal_Axial_50.png\" width=\"100%\"></a></td>"	        >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Thal_Axial_75.png\"><img src=\""${sub2}"/Thal_Axial_75.png\" width=\"100%\"></a></td>"    		>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Thal_Coronal_25.png\"><img src=\""${sub2}"/Thal_Coronal_25.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Thal_Coronal_50.png\"><img src=\""${sub2}"/Thal_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Thal_Coronal_75.png\"><img src=\""${sub2}"/Thal_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> CAUDATE BASELINE </FONT> </th>"                       	>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/Caud_Axial_25.png\"><img src=\""${sub1}"/Caud_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Caud_Axial_50.png\"><img src=\""${sub1}"/Caud_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Caud_Axial_75.png\"><img src=\""${sub1}"/Caud_Axial_75.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Caud_Coronal_25.png\"><img src=\""${sub1}"/Caud_Coronal_25.png\" width=\"100%\"></a></td>"         	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Caud_Coronal_50.png\"><img src=\""${sub1}"/Caud_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Caud_Coronal_75.png\"><img src=\""${sub1}"/Caud_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> CAUDATE FOLLOW UP </FONT> </th></tr>"                    >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub2}"/Caud_Axial_25.png\"><img src=\""${sub2}"/Caud_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Caud_Axial_50.png\"><img src=\""${sub2}"/Caud_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Caud_Axial_75.png\"><img src=\""${sub2}"/Caud_Axial_75.png\" width=\"100%\"></a></td>"	        >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Caud_Coronal_25.png\"><img src=\""${sub2}"/Caud_Coronal_25.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Caud_Coronal_50.png\"><img src=\""${sub2}"/Caud_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Caud_Coronal_75.png\"><img src=\""${sub2}"/Caud_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> PALLIDUM BASELINE </FONT> </th></tr>"                    >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/Pall_Axial_25.png\"><img src=\""${sub1}"/Pall_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Pall_Axial_50.png\"><img src=\""${sub1}"/Pall_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Pall_Axial_75.png\"><img src=\""${sub1}"/Pall_Axial_75.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Pall_Coronal_25.png\"><img src=\""${sub1}"/Pall_Coronal_25.png\" width=\"100%\"></a></td>"      	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Pall_Coronal_50.png\"><img src=\""${sub1}"/Pall_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Pall_Coronal_75.png\"><img src=\""${sub1}"/Pall_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> PALLIDUM FOLLOW UP </FONT> </th></tr>"                   >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub2}"/Pall_Axial_25.png\"><img src=\""${sub2}"/Pall_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Pall_Axial_50.png\"><img src=\""${sub2}"/Pall_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Pall_Axial_75.png\"><img src=\""${sub2}"/Pall_Axial_75.png\" width=\"100%\"></a></td>"	        >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Pall_Coronal_25.png\"><img src=\""${sub2}"/Pall_Coronal_25.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Pall_Coronal_50.png\"><img src=\""${sub2}"/Pall_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Pall_Coronal_75.png\"><img src=\""${sub2}"/Pall_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> PUTAMEN BASELINE </FONT> </th></tr>"                    	>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/Put_Axial_25.png\"><img src=\""${sub1}"/Put_Axial_25.png\" width=\"100%\"></a></td>"        	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Put_Axial_50.png\"><img src=\""${sub1}"/Put_Axial_50.png\" width=\"100%\"></a></td>"              	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Put_Axial_75.png\"><img src=\""${sub1}"/Put_Axial_75.png\" width=\"100%\"></a></td>"              	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Put_Coronal_25.png\"><img src=\""${sub1}"/Put_Coronal_25.png\" width=\"100%\"></a></td>"    	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Put_Coronal_50.png\"><img src=\""${sub1}"/Put_Coronal_50.png\" width=\"100%\"></a></td>"            >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Put_Coronal_75.png\"><img src=\""${sub1}"/Put_Coronal_75.png\" width=\"100%\"></a></td></tr>"       >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> PUTAMEN FOLLOW UP </FONT> </th></tr>"                    >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub2}"/Put_Axial_25.png\"><img src=\""${sub2}"/Put_Axial_25.png\" width=\"100%\"></a></td>"           >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Put_Axial_50.png\"><img src=\""${sub2}"/Put_Axial_50.png\" width=\"100%\"></a></td>"        	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Put_Axial_75.png\"><img src=\""${sub2}"/Put_Axial_75.png\" width=\"100%\"></a></td>"	        >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Put_Coronal_25.png\"><img src=\""${sub2}"/Put_Coronal_25.png\" width=\"100%\"></a></td>"            >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Put_Coronal_50.png\"><img src=\""${sub2}"/Put_Coronal_50.png\" width=\"100%\"></a></td>"            >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Put_Coronal_75.png\"><img src=\""${sub2}"/Put_Coronal_75.png\" width=\"100%\"></a></td></tr>"       >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> AMYGDALA BASELINE </FONT> </th></tr>"      		>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/Amyg_Axial_25.png\"><img src=\""${sub1}"/Amyg_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Amyg_Axial_50.png\"><img src=\""${sub1}"/Amyg_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Amyg_Axial_75.png\"><img src=\""${sub1}"/Amyg_Axial_75.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Amyg_Coronal_25.png\"><img src=\""${sub1}"/Amyg_Coronal_25.png\" width=\"100%\"></a></td>"      	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Amyg_Coronal_50.png\"><img src=\""${sub1}"/Amyg_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Amyg_Coronal_75.png\"><img src=\""${sub1}"/Amyg_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> AMYGDALA FOLLOW UP </FONT> </th></tr>"                   >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub2}"/Amyg_Axial_25.png\"><img src=\""${sub2}"/Amyg_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Amyg_Axial_50.png\"><img src=\""${sub2}"/Amyg_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Amyg_Axial_75.png\"><img src=\""${sub2}"/Amyg_Axial_75.png\" width=\"100%\"></a></td>"	        >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Amyg_Coronal_25.png\"><img src=\""${sub2}"/Amyg_Coronal_25.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Amyg_Coronal_50.png\"><img src=\""${sub2}"/Amyg_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Amyg_Coronal_75.png\"><img src=\""${sub2}"/Amyg_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> HIPPOCAMPUS BASELINE </FONT> </th></tr>"                 >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/Hip_Axial_25.png\"><img src=\""${sub1}"/Hip_Axial_25.png\" width=\"100%\"></a></td>"       	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Hip_Axial_50.png\"><img src=\""${sub1}"/Hip_Axial_50.png\" width=\"100%\"></a></td>"              	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Hip_Axial_75.png\"><img src=\""${sub1}"/Hip_Axial_75.png\" width=\"100%\"></a></td>"              	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Hip_Coronal_25.png\"><img src=\""${sub1}"/Hip_Coronal_25.png\" width=\"100%\"></a></td>"         	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Hip_Coronal_50.png\"><img src=\""${sub1}"/Hip_Coronal_50.png\" width=\"100%\"></a></td>"            >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/Hip_Coronal_75.png\"><img src=\""${sub1}"/Hip_Coronal_75.png\" width=\"100%\"></a></td></tr>"       >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> HIPPOCAMPUS FOLLOW UP </FONT> </th></tr>" 		>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub2}"/Hip_Axial_25.png\"><img src=\""${sub2}"/Hip_Axial_25.png\" width=\"100%\"></a></td>"           >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Hip_Axial_50.png\"><img src=\""${sub2}"/Hip_Axial_50.png\" width=\"100%\"></a></td>"              	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Hip_Axial_75.png\"><img src=\""${sub2}"/Hip_Axial_75.png\" width=\"100%\"></a></td>"              	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Hip_Coronal_25.png\"><img src=\""${sub2}"/Hip_Coronal_25.png\" width=\"100%\"></a></td>"       	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Hip_Coronal_50.png\"><img src=\""${sub2}"/Hip_Coronal_50.png\" width=\"100%\"></a></td>"            >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/Hip_Coronal_75.png\"><img src=\""${sub2}"/Hip_Coronal_75.png\" width=\"100%\"></a></td></tr>"       >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> ACCUMBENS BASELINE </FONT> </th></tr>"                   >> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td> <a href=\"file:"${sub1}"/NAcc_Axial_25.png\"><img src=\""${sub1}"/NAcc_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/NAcc_Axial_50.png\"><img src=\""${sub1}"/NAcc_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/NAcc_Axial_75.png\"><img src=\""${sub1}"/NAcc_Axial_75.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/NAcc_Coronal_25.png\"><img src=\""${sub1}"/NAcc_Coronal_25.png\" width=\"100%\"></a></td>"      	>> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/NAcc_Coronal_50.png\"><img src=\""${sub1}"/NAcc_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub1}"/NAcc_Coronal_75.png\"><img src=\""${sub1}"/NAcc_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> ACCUMBENS FOLLOW UP </FONT> </th></tr>"			>> ENIGMA_LONG_Sub${i}.html  
echo "<tr> <td> <a href=\"file:"${sub2}"/NAcc_Axial_25.png\"><img src=\""${sub2}"/NAcc_Axial_25.png\" width=\"100%\"></a></td>"         >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/NAcc_Axial_50.png\"><img src=\""${sub2}"/NAcc_Axial_50.png\" width=\"100%\"></a></td>"              >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/NAcc_Axial_75.png\"><img src=\""${sub2}"/NAcc_Axial_75.png\" width=\"100%\"></a></td>"	        >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/NAcc_Coronal_25.png\"><img src=\""${sub2}"/NAcc_Coronal_25.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/NAcc_Coronal_50.png\"><img src=\""${sub2}"/NAcc_Coronal_50.png\" width=\"100%\"></a></td>"          >> ENIGMA_LONG_Sub${i}.html
echo "<td> <a href=\"file:"${sub2}"/NAcc_Coronal_75.png\"><img src=\""${sub2}"/NAcc_Coronal_75.png\" width=\"100%\"></a></td></tr>"     >> ENIGMA_LONG_Sub${i}.html

echo "</table> <table>" 														>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <th colspan=\"6\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=8> CORTICAL STRUCTURES </FONT> </th> </tr>"                 >> ENIGMA_LONG_Sub${i}.html
echo "<tr><th colspan=\"4\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> CORTICAL STRUCTURES BASELINE </FONT> </th></tr>"		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Axial_20.png\"><img src=\""$sub1"/Cortical_set_Axial_70_20.png\" width=\"100%\" ></a></td>" 		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Axial_40.png\"><img src=\""$sub1"/Cortical_set_Axial_70_40.png\" width=\"100%\" ></a></td>" 		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Axial_50.png\"><img src=\""$sub1"/Cortical_set_Axial_70_50.png\" width=\"100%\" ></a></td>"		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Axial_60.png\"><img src=\""$sub1"/Cortical_set_Axial_70_60.png\" width=\"100%\" ></a></td>"		>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td><a href=\"file:"${sub1}"/Cortical_set_Coronal_20.png\"><img src=\""$sub1"/Cortical_set_Coronal_70_20.png\" width=\"100%\" ></a></td>"	>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Coronal_40.png\"><img src=\""$sub1"/Cortical_set_Coronal_70_40.png\" width=\"100%\" ></a></td>"		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Coronal_50.png\"><img src=\""$sub1"/Cortical_set_Coronal_70_50.png\" width=\"100%\" ></a></td>"		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/Cortical_set_Coronal_60.png\"><img src=\""$sub1"/Cortical_set_Coronal_70_60.png\" width=\"100%\" ></a></td>"		>> ENIGMA_LONG_Sub${i}.html
echo "</tr> <tr> <th colspan=\"4\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> CORTICAL STRUCTURES FOLLOW UP </FONT> </th></tr>"			>> ENIGMA_LONG_Sub${i}.html  		    	
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Axial_20.png\"><img src=\""$sub2"/Cortical_set_Axial_70_20.png\" width=\"100%\" ></a></td>" 		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Axial_40.png\"><img src=\""$sub2"/Cortical_set_Axial_70_40.png\" width=\"100%\" ></a></td>" 		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Axial_50.png\"><img src=\""$sub2"/Cortical_set_Axial_70_50.png\" width=\"100%\" ></a></td>"     	>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Axial_60.png\"><img src=\""$sub2"/Cortical_set_Axial_70_60.png\" width=\"100%\" ></a></td>"     	>> ENIGMA_LONG_Sub${i}.html
echo "<tr> <td><a href=\"file:"${sub2}"/Cortical_set_Coronal_20.png\"><img src=\""$sub2"/Cortical_set_Coronal_70_20.png\" width=\"100%\" ></a></td>"    >> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Coronal_40.png\"><img src=\""$sub2"/Cortical_set_Coronal_70_40.png\" width=\"100%\" ></a></td>" 	>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Coronal_50.png\"><img src=\""$sub2"/Cortical_set_Coronal_70_50.png\" width=\"100%\" ></a></td>" 	>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/Cortical_set_Coronal_60.png\"><img src=\""$sub2"/Cortical_set_Coronal_70_60.png\" width=\"100%\" ></a></td>" 	>> ENIGMA_LONG_Sub${i}.html
echo "</table> <table>"																	>> ENIGMA_LONG_Sub${i}.html 

echo "</table> <table>"                                         											>> ENIGMA_LONG_Sub${i}.html
echo "<tr><th colspan=\"4\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> CORTICAL RECONSTRUCTION BASELINE </FONT> </th></tr>"			>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/lh.lat.hr.tif\"><img src=\""$sub1"/lh.lat.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/lh.med.hr.tif\"><img src=\""$sub1"/lh.med.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/rh.lat.hr.tif\"><img src=\""$sub1"/rh.lat.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub1}"/rh.med.hr.tif\"><img src=\""$sub1"/rh.med.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "</tr> <tr> <th colspan=\"4\"> <FONT COLOR=BLACK FACE=\"Geneva, Arial\" SIZE=5> CORTICAL RECONSTRUCTION FOLLOW UP </FONT> </th></tr>" 		>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/lh.lat.hr.tif\"><img src=\""$sub2"/lh.lat.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/lh.med.hr.tif\"><img src=\""$sub2"/lh.med.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/rh.lat.hr.tif\"><img src=\""$sub2"/rh.lat.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "<td><a href=\"file:"${sub2}"/rh.med.hr.tif\"><img src=\""$sub2"/rh.med.lr.tif\" width=\"100%\" ></a></td>"     					>> ENIGMA_LONG_Sub${i}.html
echo "</table>"																		>> ENIGMA_LONG_Sub${i}.html

echo '<hr width="100%">'                                                										>>  ENIGMA_LONG_Sub${i}.html
echo '<Center><a href="ENIGMA_LONG_Sub'${prev}'.html">Previous Subject</a>&nbsp;-&nbsp;<a href="ENIGMA_LONG_Sub'${next}'.html">Next Subject</a> </center>' >> ENIGMA_LONG_Sub${i}.html
echo '<hr width="100%">'                                                										>>  ENIGMA_LONG_Sub${i}.html
(( i += 1 ))
done < $subjects

echo "</body>"                                                                              			>> ENIGMA_LONG_QC.html
echo "</html>"                                                                              			>> ENIGMA_LONG_QC.html


