# Outlier Detection (July 31, 2014; updated March 29, 2016) 
# Rachel Brouwer 
# Read in the brain measures of step 1 of the protocols 

data <- read.csv("ENIGMA_LONG.csv",stringsAsFactors=FALSE) 
data <- read.csv("~/Documents/ENIGMA/ENIGMA_plasticity/Paper1/ENIGMA_LONG_s336.csv",stringsAsFactors=FALSE)


# Check for duplicated subject IDs
if (anyDuplicated(data[,c("SubID_base")]) != 0) 
{ 
	stop('You have duplicate SubIDs at baseline in your file.\nMake sure there are no repeat SubIDs.') 
} 
if (anyDuplicated(data[,c("SubID_fup")]) != 0) 
{ 
	stop('You have duplicate SubIDs at follow-up in your file.\nMake sure there are no repeat SubIDs.') 
} 

# Create a matrix for summarizing the outlier data
# will contain the subject IDs for baseline and follow-up
# six 0/1 variables reporting whether there are low/high values for baseline/follow-up/change measures
# six lists containing the variables 



namesbase <- names(data)[4:((ncol(data)+3)/2)]
namesfup <- sub('base','fup',namesbase)
# names for left right differences and change measures 
# can use the first if data is extracted according to the longitudinal_extract.sh script
#Llist <- names(data)[c(6,8,12:16,22:23,26:32,40:73,108:141,178,180,184:188,194:195,198:204,212:245,280:313)]
Llistbase <- c('lhCortexVol_base','lhCorticalWhiteMatterVol_base','L_Cerebellum.White.Matter_base','L_Cerebellum.Cortex_base','L_Lateral.Ventricle_base','L_Inf.Lat.Vent_base','L_choroid.plexus_base','L_MeanThickness_base','L_WhiteSurfArea_base','L_thal_base','L_caud_base','L_put_base','L_pal_base','L_hippo_base','L_amyg_base','L_accumb_base','L_bankssts_thickavg_base','L_caudalanteriorcingulate_thickavg_base','L_caudalmiddlefrontal_thickavg_base','L_cuneus_thickavg_base','L_entorhinal_thickavg_base','L_fusiform_thickavg_base','L_inferiorparietal_thickavg_base','L_inferiortemporal_thickavg_base','L_isthmuscingulate_thickavg_base','L_lateraloccipital_thickavg_base','L_lateralorbitofrontal_thickavg_base','L_lingual_thickavg_base','L_medialorbitofrontal_thickavg_base','L_middletemporal_thickavg_base','L_parahippocampal_thickavg_base','L_paracentral_thickavg_base','L_parsopercularis_thickavg_base','L_parsorbitalis_thickavg_base','L_parstriangularis_thickavg_base','L_pericalcarine_thickavg_base','L_postcentral_thickavg_base','L_posteriorcingulate_thickavg_base','L_precentral_thickavg_base','L_precuneus_thickavg_base','L_rostralanteriorcingulate_thickavg_base','L_rostralmiddlefrontal_thickavg_base','L_superiorfrontal_thickavg_base','L_superiorparietal_thickavg_base','L_superiortemporal_thickavg_base','L_supramarginal_thickavg_base','L_frontalpole_thickavg_base','L_temporalpole_thickavg_base','L_transversetemporal_thickavg_base','L_insula_thickavg_base','L_bankssts_surfavg_base','L_caudalanteriorcingulate_surfavg_base','L_caudalmiddlefrontal_surfavg_base','L_cuneus_surfavg_base','L_entorhinal_surfavg_base','L_fusiform_surfavg_base','L_inferiorparietal_surfavg_base','L_inferiortemporal_surfavg_base','L_isthmuscingulate_surfavg_base','L_lateraloccipital_surfavg_base','L_lateralorbitofrontal_surfavg_base','L_lingual_surfavg_base','L_medialorbitofrontal_surfavg_base','L_middletemporal_surfavg_base','L_parahippocampal_surfavg_base','L_paracentral_surfavg_base','L_parsopercularis_surfavg_base','L_parsorbitalis_surfavg_base','L_parstriangularis_surfavg_base','L_pericalcarine_surfavg_base','L_postcentral_surfavg_base','L_posteriorcingulate_surfavg_base','L_precentral_surfavg_base','L_precuneus_surfavg_base','L_rostralanteriorcingulate_surfavg_base','L_rostralmiddlefrontal_surfavg_base','L_superiorfrontal_surfavg_base','L_superiorparietal_surfavg_base','L_superiortemporal_surfavg_base','L_supramarginal_surfavg_base','L_frontalpole_surfavg_base','L_temporalpole_surfavg_base','L_transversetemporal_surfavg_base','L_insula_surfavg_base')
Llistfup <- c('lhCortexVol_fup','lhCorticalWhiteMatterVol_fup','L_Cerebellum.White.Matter_fup','L_Cerebellum.Cortex_fup','L_Lateral.Ventricle_fup','L_Inf.Lat.Vent_fup','L_choroid.plexus_fup','L_MeanThickness_fup','L_WhiteSurfArea_fup','L_thal_fup','L_caud_fup','L_put_fup','L_pal_fup','L_hippo_fup','L_amyg_fup','L_accumb_fup','L_bankssts_thickavg_fup','L_caudalanteriorcingulate_thickavg_fup','L_caudalmiddlefrontal_thickavg_fup','L_cuneus_thickavg_fup','L_entorhinal_thickavg_fup','L_fusiform_thickavg_fup','L_inferiorparietal_thickavg_fup','L_inferiortemporal_thickavg_fup','L_isthmuscingulate_thickavg_fup','L_lateraloccipital_thickavg_fup','L_lateralorbitofrontal_thickavg_fup','L_lingual_thickavg_fup','L_medialorbitofrontal_thickavg_fup','L_middletemporal_thickavg_fup','L_parahippocampal_thickavg_fup','L_paracentral_thickavg_fup','L_parsopercularis_thickavg_fup','L_parsorbitalis_thickavg_fup','L_parstriangularis_thickavg_fup','L_pericalcarine_thickavg_fup','L_postcentral_thickavg_fup','L_posteriorcingulate_thickavg_fup','L_precentral_thickavg_fup','L_precuneus_thickavg_fup','L_rostralanteriorcingulate_thickavg_fup','L_rostralmiddlefrontal_thickavg_fup','L_superiorfrontal_thickavg_fup','L_superiorparietal_thickavg_fup','L_superiortemporal_thickavg_fup','L_supramarginal_thickavg_fup','L_frontalpole_thickavg_fup','L_temporalpole_thickavg_fup','L_transversetemporal_thickavg_fup','L_insula_thickavg_fup','L_bankssts_surfavg_fup','L_caudalanteriorcingulate_surfavg_fup','L_caudalmiddlefrontal_surfavg_fup','L_cuneus_surfavg_fup','L_entorhinal_surfavg_fup','L_fusiform_surfavg_fup','L_inferiorparietal_surfavg_fup','L_inferiortemporal_surfavg_fup','L_isthmuscingulate_surfavg_fup','L_lateraloccipital_surfavg_fup','L_lateralorbitofrontal_surfavg_fup','L_lingual_surfavg_fup','L_medialorbitofrontal_surfavg_fup','L_middletemporal_surfavg_fup','L_parahippocampal_surfavg_fup','L_paracentral_surfavg_fup','L_parsopercularis_surfavg_fup','L_parsorbitalis_surfavg_fup','L_parstriangularis_surfavg_fup','L_pericalcarine_surfavg_fup','L_postcentral_surfavg_fup','L_posteriorcingulate_surfavg_fup','L_precentral_surfavg_fup','L_precuneus_surfavg_fup','L_rostralanteriorcingulate_surfavg_fup','L_rostralmiddlefrontal_surfavg_fup','L_superiorfrontal_surfavg_fup','L_superiorparietal_surfavg_fup','L_superiortemporal_surfavg_fup','L_supramarginal_surfavg_fup','L_frontalpole_surfavg_fup','L_temporalpole_surfavg_fup','L_transversetemporal_surfavg_fup','L_insula_surfavg_fup')
Llist <- c(Llistbase,Llistfup)
#Rlist <- names(data)[c(7,9,17:21,24:25,33:39,74:107,142:175,179,181,189:193,196:197,205:211,246:279,314:347)]
Rlistbase <- c('rhCortexVol_base','rhCorticalWhiteMatterVol_base','R_Cerebellum.White.Matter_base','R_Cerebellum.Cortex_base','R_Lateral.Ventricle_base','R_Inf.Lat.Vent_base','R_choroid.plexus_base','R_MeanThickness_base','R_WhiteSurfArea_base','R_thal_base','R_caud_base','R_put_base','R_pal_base','R_hippo_base','R_amyg_base','R_accumb_base','R_bankssts_thickavg_base','R_caudalanteriorcingulate_thickavg_base','R_caudalmiddlefrontal_thickavg_base','R_cuneus_thickavg_base','R_entorhinal_thickavg_base','R_fusiform_thickavg_base','R_inferiorparietal_thickavg_base','R_inferiortemporal_thickavg_base','R_isthmuscingulate_thickavg_base','R_lateraloccipital_thickavg_base','R_lateralorbitofrontal_thickavg_base','R_lingual_thickavg_base','R_medialorbitofrontal_thickavg_base','R_middletemporal_thickavg_base','R_parahippocampal_thickavg_base','R_paracentral_thickavg_base','R_parsopercularis_thickavg_base','R_parsorbitalis_thickavg_base','R_parstriangularis_thickavg_base','R_pericalcarine_thickavg_base','R_postcentral_thickavg_base','R_posteriorcingulate_thickavg_base','R_precentral_thickavg_base','R_precuneus_thickavg_base','R_rostralanteriorcingulate_thickavg_base','R_rostralmiddlefrontal_thickavg_base','R_superiorfrontal_thickavg_base','R_superiorparietal_thickavg_base','R_superiortemporal_thickavg_base','R_supramarginal_thickavg_base','R_frontalpole_thickavg_base','R_temporalpole_thickavg_base','R_transversetemporal_thickavg_base','R_insula_thickavg_base','R_bankssts_surfavg_base','R_caudalanteriorcingulate_surfavg_base','R_caudalmiddlefrontal_surfavg_base','R_cuneus_surfavg_base','R_entorhinal_surfavg_base','R_fusiform_surfavg_base','R_inferiorparietal_surfavg_base','R_inferiortemporal_surfavg_base','R_isthmuscingulate_surfavg_base','R_lateraloccipital_surfavg_base','R_lateralorbitofrontal_surfavg_base','R_lingual_surfavg_base','R_medialorbitofrontal_surfavg_base','R_middletemporal_surfavg_base','R_parahippocampal_surfavg_base','R_paracentral_surfavg_base','R_parsopercularis_surfavg_base','R_parsorbitalis_surfavg_base','R_parstriangularis_surfavg_base','R_pericalcarine_surfavg_base','R_postcentral_surfavg_base','R_posteriorcingulate_surfavg_base','R_precentral_surfavg_base','R_precuneus_surfavg_base','R_rostralanteriorcingulate_surfavg_base','R_rostralmiddlefrontal_surfavg_base','R_superiorfrontal_surfavg_base','R_superiorparietal_surfavg_base','R_superiortemporal_surfavg_base','R_supramarginal_surfavg_base','R_frontalpole_surfavg_base','R_temporalpole_surfavg_base','R_transversetemporal_surfavg_base','R_insula_surfavg_base')
Rlistfup <- c('rhCortexVol_fup','rhCorticalWhiteMatterVol_fup','R_Cerebellum.White.Matter_fup','R_Cerebellum.Cortex_fup','R_Lateral.Ventricle_fup','R_Inf.Lat.Vent_fup','R_choroid.plexus_fup','R_MeanThickness_fup','R_WhiteSurfArea_fup','R_thal_fup','R_caud_fup','R_put_fup','R_pal_fup','R_hippo_fup','R_amyg_fup','R_accumb_fup','R_bankssts_thickavg_fup','R_caudalanteriorcingulate_thickavg_fup','R_caudalmiddlefrontal_thickavg_fup','R_cuneus_thickavg_fup','R_entorhinal_thickavg_fup','R_fusiform_thickavg_fup','R_inferiorparietal_thickavg_fup','R_inferiortemporal_thickavg_fup','R_isthmuscingulate_thickavg_fup','R_lateraloccipital_thickavg_fup','R_lateralorbitofrontal_thickavg_fup','R_lingual_thickavg_fup','R_medialorbitofrontal_thickavg_fup','R_middletemporal_thickavg_fup','R_parahippocampal_thickavg_fup','R_paracentral_thickavg_fup','R_parsopercularis_thickavg_fup','R_parsorbitalis_thickavg_fup','R_parstriangularis_thickavg_fup','R_pericalcarine_thickavg_fup','R_postcentral_thickavg_fup','R_posteriorcingulate_thickavg_fup','R_precentral_thickavg_fup','R_precuneus_thickavg_fup','R_rostralanteriorcingulate_thickavg_fup','R_rostralmiddlefrontal_thickavg_fup','R_superiorfrontal_thickavg_fup','R_superiorparietal_thickavg_fup','R_superiortemporal_thickavg_fup','R_supramarginal_thickavg_fup','R_frontalpole_thickavg_fup','R_temporalpole_thickavg_fup','R_transversetemporal_thickavg_fup','R_insula_thickavg_fup','R_bankssts_surfavg_fup','R_caudalanteriorcingulate_surfavg_fup','R_caudalmiddlefrontal_surfavg_fup','R_cuneus_surfavg_fup','R_entorhinal_surfavg_fup','R_fusiform_surfavg_fup','R_inferiorparietal_surfavg_fup','R_inferiortemporal_surfavg_fup','R_isthmuscingulate_surfavg_fup','R_lateraloccipital_surfavg_fup','R_lateralorbitofrontal_surfavg_fup','R_lingual_surfavg_fup','R_medialorbitofrontal_surfavg_fup','R_middletemporal_surfavg_fup','R_parahippocampal_surfavg_fup','R_paracentral_surfavg_fup','R_parsopercularis_surfavg_fup','R_parsorbitalis_surfavg_fup','R_parstriangularis_surfavg_fup','R_pericalcarine_surfavg_fup','R_postcentral_surfavg_fup','R_posteriorcingulate_surfavg_fup','R_precentral_surfavg_fup','R_precuneus_surfavg_fup','R_rostralanteriorcingulate_surfavg_fup','R_rostralmiddlefrontal_surfavg_fup','R_superiorfrontal_surfavg_fup','R_superiorparietal_surfavg_fup','R_superiortemporal_surfavg_fup','R_supramarginal_surfavg_fup','R_frontalpole_surfavg_fup','R_temporalpole_surfavg_fup','R_transversetemporal_surfavg_fup','R_insula_surfavg_fup')
Rlist <- c(Rlistbase,Rlistfup)
LR_struct <- sub('lh','',sub('L_','',Llist))
namesLRdif <- sprintf("L-R_%s",LR_struct)
namesCHdif <- sub('base','change',namesbase)

namesall <- c(namesbase,namesfup,namesLRdif,namesCHdif)

lowerbf <- rep(NA,ncol(data)-3) 
upperbf <- rep(NA,ncol(data)-3) 
lowerCHdif <- rep(NA,length(namesCHdif)) 
upperCHdif <- rep(NA,length(namesCHdif)) 
lowerLRdif <- rep(NA,length(namesLRdif))
upperLRdif <- rep(NA,length(namesLRdif))

# compute data and add to dataframe
difCHscores <- matrix(NA, nrow=nrow(data),ncol=length(namesCHdif),dimnames=list(NULL,namesCHdif))
difLRscores <- matrix(NA, nrow=nrow(data),ncol=length(namesLRdif),dimnames=list(NULL,namesLRdif))

# Store the lower and upper limits for base and fup data 
lowerbf <- rep(NA,ncol(data)-3) 
upperbf <- rep(NA,ncol(data)-3) 

# Loop through the different structures of baseline and fup
	for (x in 4:(ncol(data)))
	{
	lowerbf[x-3] <- mean(data[,x],na.rm=T) - 2.698*sd(data[,x],na.rm=T) 
	upperbf[x-3] <- mean(data[,x],na.rm=T) + 2.698*sd(data[,x],na.rm=T) 
	} 
	names(lowerbf) <- names(data)[4:ncol(data)]
    names(upperbf) <- names(data)[4:ncol(data)]


# Looping through the left-right differences of the structures
for (x in 1:length(Llist))
{
	difLRscores[,x] <- data[,Llist[x]]  - data[,Rlist[x]]
	lowerLRdif[x] <- mean(difLRscores[,x],na.rm=T) - 2.698*sd(difLRscores[,x],na.rm=T)
	upperLRdif[x] <- mean(difLRscores[,x],na.rm=T) + 2.698*sd(difLRscores[,x],na.rm=T)
}
	names(lowerLRdif) <- namesLRdif
	names(upperLRdif) <- namesLRdif
		
# Looping through the changes measures for all structures
# Divide by follow-up duration to eliminate differences due to size of interval

for (x in 1:length(namesCHdif))
{
	difCHscores[,x] <- (data[,namesfup[x]] - data[,namesbase[x]]) / data[,'fup_duration']
	lowerCHdif[x] <- mean(difCHscores[,x],na.rm=T) - 2.698*sd(difCHscores[,x],na.rm=T)
	upperCHdif[x] <- mean(difCHscores[,x],na.rm=T) + 2.698*sd(difCHscores[,x],na.rm=T)
}
	names(lowerCHdif) <- namesCHdif
	names(upperCHdif) <- namesCHdif


# determine which subjects are outliers for each structure
outliers_low <- data.frame(matrix(0,nrow=dim(data)[1],ncol=length(namesall)+2,dimnames=list(NULL,c(names(data)[1:2],namesall))),check.names=F)
outliers_high <- data.frame(matrix(0,nrow=dim(data)[1],ncol=length(namesall)+2,dimnames=list(NULL,c(names(data)[1:2],namesall))),check.names=F)
data <- cbind(data,difLRscores,difCHscores)
lower <- c(lowerbf,lowerLRdif,lowerCHdif)
upper <- c(upperbf,upperLRdif,upperCHdif)


	# cat('Please check the following subjects closely using the QC methods provided in Step 2 of the cortical protocols.\n') 
	
	# Loop through each subject report which structures are outliers 
	for(i in 1:nrow(data))
	{ 
		outliers_low[i,1] <- data[i,1]
		outliers_low[i,2] <- data[i,2]
		outliers_high[i,1] <- data[i,1]
		outliers_high[i,2] <- data[i,2]
 		lowind <- which(data[i,-c(1:3)] < lower) 
		upind <- which(data[i,-c(1:3)] > upper) 
		outliers_low[i,lowind+2] <- 1
		outliers_high[i,upind+2] <- 1
	}
	
	# report total number of outliers for each subject and list regions to file
	# print an outlier report
	# separately for global, subcortical and cortical structures for easier detection of outliers
	# GLOBnames <- namesall[c(1:22,174:194,345:353,429:437,513:534)]
	GLOBnames <- c('IntraCranialVol_base','BrainSegNotVent_base','lhCortexVol_base','rhCortexVol_base','lhCorticalWhiteMatterVol_base','rhCorticalWhiteMatterVol_base','X3rd.Ventricle_base','X4th.Ventricle_base','L_Cerebellum.White.Matter_base','L_Cerebellum.Cortex_base','L_Lateral.Ventricle_base','L_Inf.Lat.Vent_base','L_choroid.plexus_base','R_Cerebellum.White.Matter_base','R_Cerebellum.Cortex_base','R_Lateral.Ventricle_base','R_Inf.Lat.Vent_base','R_choroid.plexus_base','L_MeanThickness_base','L_WhiteSurfArea_base','R_MeanThickness_base','R_WhiteSurfArea_base','IntraCranialVol_fup','BrainSegNotVent_fup','lhCortexVol_fup','rhCortexVol_fup','lhCorticalWhiteMatterVol_fup','rhCorticalWhiteMatterVol_fup','X3rd.Ventricle_fup','X4th.Ventricle_fup','L_Cerebellum.White.Matter_fup','L_Cerebellum.Cortex_fup','L_Lateral.Ventricle_fup','L_Inf.Lat.Vent_fup','L_choroid.plexus_fup','R_Cerebellum.White.Matter_fup','R_Cerebellum.Cortex_fup','R_Lateral.Ventricle_fup','R_Inf.Lat.Vent_fup','R_choroid.plexus_fup','L_MeanThickness_fup','L_WhiteSurfArea_fup','R_MeanThickness_fup','R_WhiteSurfArea_fup','L-R_CortexVol_base','L-R_CorticalWhiteMatterVol_base','L-R_Cerebellum.White.Matter_base','L-R_Cerebellum.Cortex_base','L-R_Lateral.Ventricle_base','L-R_Inf.Lat.Vent_base','L-R_choroid.plexus_base','L-R_MeanThickness_base','L-R_WhiteSurfArea_base','L-R_CortexVol_fup','L-R_CorticalWhiteMatterVol_fup','L-R_Cerebellum.White.Matter_fup','L-R_Cerebellum.Cortex_fup','L-R_Lateral.Ventricle_fup','L-R_Inf.Lat.Vent_fup','L-R_choroid.plexus_fup','L-R_MeanThickness_fup','L-R_WhiteSurfArea_fup','IntraCranialVol_change','BrainSegNotVent_change','lhCortexVol_change','rhCortexVol_change','lhCorticalWhiteMatterVol_change','rhCorticalWhiteMatterVol_change','X3rd.Ventricle_change','X4th.Ventricle_change','L_Cerebellum.White.Matter_change','L_Cerebellum.Cortex_change','L_Lateral.Ventricle_change','L_Inf.Lat.Vent_change','L_choroid.plexus_change','R_Cerebellum.White.Matter_change','R_Cerebellum.Cortex_change','R_Lateral.Ventricle_change','R_Inf.Lat.Vent_change','R_choroid.plexus_change','L_MeanThickness_change','L_WhiteSurfArea_change','R_MeanThickness_change','R_WhiteSurfArea_change')
	# SUBnames <- namesall[c(23:36,195:208,354:360,438:444,535:548)]
	SUBnames <- c('L_thal_base','L_caud_base','L_put_base','L_pal_base','L_hippo_base','L_amyg_base','L_accumb_base','R_thal_base','R_caud_base','R_put_base','R_pal_base','R_hippo_base','R_amyg_base','R_accumb_base','L_thal_fup','L_caud_fup','L_put_fup','L_pal_fup','L_hippo_fup','L_amyg_fup','L_accumb_fup','R_thal_fup','R_caud_fup','R_put_fup','R_pal_fup','R_hippo_fup','R_amyg_fup','R_accumb_fup','L-R_thal_base','L-R_caud_base','L-R_put_base','L-R_pal_base','L-R_hippo_base','L-R_amyg_base','L-R_accumb_base','L-R_thal_fup','L-R_caud_fup','L-R_put_fup','L-R_pal_fup','L-R_hippo_fup','L-R_amyg_fup','L-R_accumb_fup','L_thal_change','L_caud_change','L_put_change','L_pal_change','L_hippo_change','L_amyg_change','L_accumb_change','R_thal_change','R_caud_change','R_put_change','R_pal_change','R_hippo_change','R_amyg_change','R_accumb_change')
	CORTnames <- namesall[!(namesall %in% c(GLOBnames,SUBnames))]	
	
	
report <- data.frame(data[,1:2],rowSums(cbind(outliers_low[,-c(1,2)],outliers_high[,-c(1,2)])))
names(report) <- c('SubjID_base','SubjID_fup','NR_outliers')

message <- sprintf("Number of outliers per subject\n")
breaks <- sprintf("*******************************\n")
spaces <- sprintf("\n")
cat(message,file="outliers_long.txt",append=F)
cat(breaks,file="outliers_long.txt",append=T)
suppressWarnings(write.table(report,"outliers_long.txt",row.names=F, col.names=F, append=T))
cat(spaces,file="outliers_long.txt",append=T)
cat(breaks,file="outliers_long.txt",append=T)



str <- c('GLOB','SUB','CORT')
structures <- list(GLOBnames,SUBnames,CORTnames)
for (j in 1:3)
{
for (i in 1:nrow(data))
{
if (rowSums(outliers_low[i,structures[[j]]]) > 0)
{
        message <- sprintf("%s %s %s LOW",outliers_low[i,1],outliers_low[i,2],str[j]) 
        outlierlist <- c(which(outliers_low[i,structures[[j]]] > 0))
        cat(unlist(c(message,structures[[j]][outlierlist])),file="outliers_long.txt",append=T)
        cat(spaces,file="outliers_long.txt",append=T)
}
}
cat(breaks,file="outliers_long.txt",append=T)

for (i in 1:nrow(data))
{
if (rowSums(outliers_high[i,structures[[j]]]) > 0)
{
        message <- sprintf("%s %s %s HIGH",outliers_high[i,1],outliers_high[i,2],str[j])
        outlierlist <- c(which(outliers_high[i,structures[[j]]] > 0))
        cat(unlist(c(message,structures[[j]][outlierlist])),file="outliers_long.txt",append=T)        
		cat(spaces,file="outliers_long.txt",append=T)
}
}

cat(breaks,file="outliers_long.txt",append=T)
}




